@@ -189,6 +189,18 @@ class AskdataPandasExtension:
         r = response.json()
         agent_id = r["agentId"]
 
+        s = requests.Session()
+        s.keep_alive = False
+        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+        s.mount('https://', HTTPAdapter(max_retries=retries))
+        authentication_url = askdata_url + '/security/me'
+
+        headers = {"Authorization": "Bearer" + " " + self._token}
+        response = s.get(url=authentication_url, headers=headers)
+        response.raise_for_status()
+        r = response.json()
+        self.user_id = r["id"]
+
         url = askdata_url + "/smartbot/agents/" + agent_id + "/ask"
 
         s = requests.Session()
@@ -199,10 +211,10 @@ class AskdataPandasExtension:
         body = {
             "message": with_query,
             "language": lang.lower(),
-            "userId": self.userid
+            "userId": self.user_id
         }
 
-        response = s.post(url=url, json=body, headers=self._headers)
+        response = s.post(url=url, json=body, headers=headers)
         response.raise_for_status()
         result = response.json()["result"]
         df_query = pd.DataFrame(data=result[0]["attachment"]["body"][0]["details"]["rows"],
