@@ -72,20 +72,19 @@ class Insight_Definition:
                     for query in query_ids:
                         if(str(field_codes[field]).startswith(query)):
                            if(str(column["id"]).startswith(query)):
-                               settings[field + "_id"] = column["code"]
+                               settings[field + "_id"] = column["id"]
                                found = True
                                break
                            else:
                                continue
                         else:
                             found = True
-                            settings[field + "_id"] = column["code"]
+                            settings[field + "_id"] = column["id"]
                             break
 
         for key in values.keys():
-            settings[key] = values[key]
+            settings[key + "_id"] = values[key]
 
-        print(settings)
         body = {
             "id" : widget_id,
             "type": "widget",
